commit-grub
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[1739] forgot to checkin last commit


From: Robert Millan
Subject: [1739] forgot to checkin last commit
Date: Sun, 27 Jul 2008 15:41:44 +0000

Revision: 1739
          http://svn.sv.gnu.org/viewvc/?view=rev&root=grub&revision=1739
Author:   robertmh
Date:     2008-07-27 15:41:43 +0000 (Sun, 27 Jul 2008)

Log Message:
-----------
forgot to checkin last commit

Modified Paths:
--------------
    trunk/grub2/commands/help.c

Modified: trunk/grub2/commands/help.c
===================================================================
--- trunk/grub2/commands/help.c 2008-07-27 14:46:45 UTC (rev 1738)
+++ trunk/grub2/commands/help.c 2008-07-27 15:41:43 UTC (rev 1739)
@@ -22,10 +22,6 @@
 #include <grub/arg.h>
 #include <grub/misc.h>
 
-/* XXX: This has to be changed into a function so the screen can be
-   optimally used.  */
-#define TERM_WIDTH     80
-
 static grub_err_t
 grub_cmd_help (struct grub_arg_list *state __attribute__ ((unused)), int argc,
               char **args)
@@ -43,16 +39,16 @@
        {
          if (cmd->flags & GRUB_COMMAND_FLAG_CMDLINE)
            {
-             char description[TERM_WIDTH / 2];
+             char description[GRUB_TERM_WIDTH / 2];
              int desclen = grub_strlen (cmd->summary);
              
              /* Make a string with a length of TERM_WIDTH / 2 - 1 filled
                 with the description followed by spaces.  */
-             grub_memset (description, ' ', TERM_WIDTH / 2 - 1);
-             description[TERM_WIDTH / 2 - 1] = '\0';
+             grub_memset (description, ' ', GRUB_TERM_WIDTH / 2 - 1);
+             description[GRUB_TERM_WIDTH / 2 - 1] = '\0';
              grub_memcpy (description, cmd->summary,
-                          (desclen < TERM_WIDTH / 2 - 1 
-                           ? desclen : TERM_WIDTH / 2 - 1));
+                          (desclen < GRUB_TERM_WIDTH / 2 - 1 
+                           ? desclen : GRUB_TERM_WIDTH / 2 - 1));
              
              grub_printf ("%s%s", description, (cnt++) % 2 ? "\n" : " ");
            }
@@ -43,16 +39,16 @@
              int desclen = grub_strlen (cmd->summary);
              
-             /* Make a string with a length of TERM_WIDTH / 2 - 1 filled
+             /* Make a string with a length of GRUB_TERM_WIDTH / 2 - 1 filled
                 with the description followed by spaces.  */






reply via email to

[Prev in Thread] Current Thread [Next in Thread]